@@ -37,37 +37,37 @@ KU_UserLDAP::KU_UserLDAP(KU_PrefsBase *cfg) : KU_Users( cfg )
   schemaversion = 0;
 
   if ( mCfg->ldapssl() )
-    mUrl.setProtocol("ldaps");
+    mUrl.setProtocol(QLatin1String( "ldaps" ));
   else
-    mUrl.setProtocol("ldap");
+    mUrl.setProtocol(QLatin1String( "ldap" ));
 
   mUrl.setHost( mCfg->ldaphost() );
   mUrl.setPort( mCfg->ldapport() );
-  mUrl.setDn( KLDAP::LdapDN( mCfg->ldapuserbase() + ',' + mCfg->ldapdn() ) );
+  mUrl.setDn( KLDAP::LdapDN( mCfg->ldapuserbase() + QLatin1Char( ',' ) + mCfg->ldapdn() ) );
   if ( !mCfg->ldapanon() ) {
     mUrl.setUser( mCfg->ldapuser() );
     mUrl.setPass( mCfg->ldappassword() );
     QString binddn = mCfg->ldapbinddn();
-    if ( !binddn.isEmpty() ) 
-      mUrl.setExtension( "bindname",binddn );
+    if ( !binddn.isEmpty() )
+      mUrl.setExtension( QLatin1String( "bindname" ),binddn );
   }
   mUrl.setFilter( mCfg->ldapuserfilter() );
 
-  if ( mCfg->ldaptls() ) mUrl.setExtension( "x-tls", "" );
+  if ( mCfg->ldaptls() ) mUrl.setExtension( QLatin1String( "x-tls" ), QLatin1String( "" ) );
   if ( mCfg->ldapsasl() ) {
-    mUrl.setExtension( "x-sasl", "" );
-    mUrl.setExtension( "x-mech", mCfg->ldapsaslmech() );
+    mUrl.setExtension( QLatin1String( "x-sasl" ), QLatin1String( "" ) );
+    mUrl.setExtension( QLatin1String( "x-mech" ), mCfg->ldapsaslmech() );
   }
 
   mUrl.setScope(KLDAP::LdapUrl::One);
-  mUrl.setExtension("x-dir","base");
+  mUrl.setExtension(QLatin1String( "x-dir" ),QLatin1String( "base" ));
 
   if ( mCfg->ldaptimelimit() )
-    mUrl.setExtension("x-timelimit",QString::number(mCfg->ldaptimelimit()));
+    mUrl.setExtension(QLatin1String( "x-timelimit" ),QString::number(mCfg->ldaptimelimit()));
   if ( mCfg->ldapsizelimit() )
-    mUrl.setExtension("x-sizelimit",QString::number(mCfg->ldapsizelimit()));
+    mUrl.setExtension(QLatin1String( "x-sizelimit" ),QString::number(mCfg->ldapsizelimit()));
   if ( mCfg->ldappagesize() )
-    mUrl.setExtension("x-pagesize",QString::number(mCfg->ldappagesize()));
+    mUrl.setExtension(QLatin1String( "x-pagesize" ),QString::number(mCfg->ldappagesize()));
 
   caps = Cap_Passwd | Cap_Disable_POSIX;
   if ( mCfg->ldapshadow() ) caps |= Cap_Shadow;
@@ -106,101 +106,101 @@ void KU_UserLDAP::data( KLDAP::LdapSearch *, const KLDAP::LdapObject& data )
   KLDAP::LdapAttrMap attrs = data.attributes();
   for ( KLDAP::LdapAttrMap::ConstIterator it = attrs.constBegin(); it != attrs.constEnd(); ++it ) {
     QString name = it.key().toLower();
-    if ( name == "objectclass" ) {
+    if ( name == QLatin1String( "objectclass" ) ) {
       for ( KLDAP::LdapAttrValue::ConstIterator it2 = (*it).constBegin(); it2 != (*it).constEnd(); ++it2 ) {
         if ( (*it2).toLower() == "posixaccount" )
             user.setCaps( user.getCaps() | KU_User::Cap_POSIX );
-        else if ( (*it2).toLower() == "sambasamaccount" )
+        else if ( (*it2).toLower() ==  "sambasamaccount" )
             user.setCaps( user.getCaps() | KU_User::Cap_Samba );
 	else if ( (*it2).toLower() != "inetorgperson" &&
 	          (*it2).toLower() != "shadowaccount" &&
                   (*it2).toLower() != "account" )
-            objectclasses.append( (*it2) );
+            objectclasses.append( QLatin1String( (*it2) ) );
       }
       continue;
     }
-                      
+
     KLDAP::LdapAttrValue values = (*it);
     if ( values.isEmpty() ) continue;
     QString val = QString::fromUtf8( values.first(), values.first().size() );
-    if ( name == "uidnumber" )
+    if ( name == QLatin1String( "uidnumber" ) )
       user.setUID( val.toLong() );
-    else if ( name == "gidnumber" )
+    else if ( name == QLatin1String( "gidnumber" ) )
       user.setGID( val.toLong() );
-    else if ( name == "uid" || name == "userid" )
+    else if ( name == QLatin1String( "uid" ) || name == QLatin1String( "userid" ) )
       user.setName( val );
-    else if ( name == "sn" )
+    else if ( name == QLatin1String( "sn" ) )
       user.setSurname( val );
-    else if ( name == "mail" )
+    else if ( name == QLatin1String( "mail" ) )
       user.setEmail( val );
-    else if ( name == "homedirectory" )
+    else if ( name == QLatin1String( "homedirectory" ) )
       user.setHomeDir( val );
-    else if ( name == "loginshell" )
+    else if ( name == QLatin1String( "loginshell" ) )
       user.setShell( val );
-    else if ( name == "postaladdress" )
+    else if ( name == QLatin1String( "postaladdress" ) )
       user.setAddress( val );
-    else if ( name == "telephonenumber" ) {
+    else if ( name == QLatin1String( "telephonenumber" ) ) {
       user.setOffice1( val );
       if ( values.size() > 1 )
         user.setOffice2( QString::fromUtf8( values[1], values[1].size() ) );
-    } else if ( name == "gecos" ) {
+    } else if ( name == QLatin1String( "gecos" ) ) {
       QString name, f1, f2, f3;
       parseGecos( values.first(), name, f1, f2, f3 );
       if ( user.getFullName().isEmpty() ) user.setFullName( val );
       if ( user.getOffice1().isEmpty() ) user.setOffice1( f1 );
       if ( user.getOffice2().isEmpty() ) user.setOffice2( f1 );
       if ( user.getAddress().isEmpty() ) user.setAddress( f1 );
-    } else if ( name == "cn" ) {
+    } else if ( name == QLatin1String( "cn" ) ) {
       if ( user.getFullName().isEmpty() || mCfg->ldapcnfullname() )
         user.setFullName( val );
       if ( user.getName().isEmpty() )
         user.setName( val );
-    } else if ( name == "displayname" ) {
+    } else if ( name == QLatin1String( "displayname" ) ) {
       user.setFullName( val );
-    } else if ( name == "userpassword" ) {
+    } else if ( name == QLatin1String( "userpassword" ) ) {
       if ( !val.isEmpty() ) user.setDisabled( false );
       user.setPwd( val );
-    } else if ( name == "shadowlastchange" ) {
+    } else if ( name == QLatin1String( "shadowlastchange" ) ) {
       if ( user.getLastChange() == 0 ) //sambapwdlastset is more precise
         user.setLastChange( daysToTime( val.toLong() ) );
-    } else if ( name == "shadowmin" )
+    } else if ( name == QLatin1String( "shadowmin" ) )
       user.setMin( val.toInt() );
-    else if ( name == "shadowmax" )
+    else if ( name == QLatin1String( "shadowmax" ) )
       user.setMax( val.toLong() );
-    else if ( name == "shadowwarning" )
+    else if ( name == QLatin1String( "shadowwarning" ) )
       user.setWarn( val.toLong() );
-    else if ( name == "shadowinactive" )
+    else if ( name == QLatin1String( "shadowinactive" ) )
       user.setInactive( val.toLong() );
-    else if ( name == "shadowexpire" )
+    else if ( name == QLatin1String( "shadowexpire" ) )
       user.setExpire( val.toLong() );
-    else if ( name == "shadowflag" )
+    else if ( name == QLatin1String( "shadowflag" ) )
       user.setFlag( val.toLong() );
-    else if ( name == "sambaacctflags" ) {
-      if ( !val.contains( 'D' ) ) user.setDisabled( false );
-    } else if ( name == "sambasid" )
+    else if ( name == QLatin1String( "sambaacctflags" ) ) {
+      if ( !val.contains( QLatin1Char( 'D' ) ) ) user.setDisabled( false );
+    } else if ( name == QLatin1String( "sambasid" ) )
       user.setSID( val );
-    else if ( name == "sambaprimarygroupsid" )
+    else if ( name == QLatin1String( "sambaprimarygroupsid" ) )
       user.setPGSID( val );
-    else if ( name == "sambalmpassword" )
+    else if ( name == QLatin1String( "sambalmpassword" ) )
       user.setLMPwd( val );
-    else if ( name == "sambantpassword" )
+    else if ( name == QLatin1String( "sambantpassword" ) )
       user.setNTPwd( val );
-    else if ( name == "sambahomepath" )
+    else if ( name == QLatin1String( "sambahomepath" ) )
       user.setHomePath( val );
-    else if ( name == "sambahomedrive" )
+    else if ( name == QLatin1String( "sambahomedrive" ) )
       user.setHomeDrive( val );
-    else if ( name == "sambalogonscript" )
+    else if ( name == QLatin1String( "sambalogonscript" ) )
       user.setLoginScript( val );
-    else if ( name == "sambaprofilepath" )
+    else if ( name == QLatin1String( "sambaprofilepath" ) )
       user.setProfilePath( val );
-    else if ( name == "sambauserworkstations" )
+    else if ( name == QLatin1String( "sambauserworkstations" ) )
       user.setWorkstations( val );
-    else if ( name == "sambadomainname" )
+    else if ( name == QLatin1String( "sambadomainname" ) )
       user.setDomain( val );
-    else if ( name == "sambapwdlastset" )
+    else if ( name == QLatin1String( "sambapwdlastset" ) )
       user.setLastChange( val.toLong() );
 //these new attributes introduced around samba 3.0.6
-    else if ( name == "sambapasswordhistory" || name == "sambalogonhours" )
+    else if ( name == QLatin1String( "sambapasswordhistory" ) || name == QLatin1String( "sambalogonhours" ) )
       schemaversion = 1;
 
   }
@@ -208,7 +208,7 @@ void KU_UserLDAP::data( KLDAP::LdapSearch *, const KLDAP::LdapObject& data )
   kDebug() << "new user: " << user.getName();
   if ( !objectclasses.isEmpty() ) {
     mObjectClasses.insert( count(), objectclasses );
-    kDebug() << "user: " << user.getName() << " other objectclasses: " << objectclasses.join(",");
+    kDebug() << "user: " << user.getName() << " other objectclasses: " << objectclasses.join(QLatin1String( "," ));
   }
   append( user );
 
@@ -235,11 +235,11 @@ bool KU_UserLDAP::reload()
   qApp->processEvents();
   KLDAP::LdapSearch search;
 
-  connect( &search, 
-    SIGNAL( data( KLDAP::LdapSearch*, const KLDAP::LdapObject& ) ), 
+  connect( &search,
+    SIGNAL( data( KLDAP::LdapSearch*, const KLDAP::LdapObject& ) ),
     this, SLOT ( data ( KLDAP::LdapSearch*, const KLDAP::LdapObject&) ) );
-  connect( &search, 
-    SIGNAL( result( KLDAP::LdapSearch* ) ), 
+  connect( &search,
+    SIGNAL( result( KLDAP::LdapSearch* ) ),
     this, SLOT ( result ( KLDAP::LdapSearch* ) ) );
 
   if (search.search( mUrl )) {
@@ -259,16 +259,16 @@ QString KU_UserLDAP::getRDN(const KU_User &user) const
 {
   switch ( mCfg->ldapuserrdn() ) {
     case KU_PrefsBase::EnumLdapuserrdn::uid:
-      return "uid=" + user.getName();
+      return QLatin1String( "uid=" ) + user.getName();
     case KU_PrefsBase::EnumLdapuserrdn::uidNumber:
-      return "uidNumber=" + QString::number( user.getUID() );
+      return QLatin1String( "uidNumber=" ) + QString::number( user.getUID() );
     case KU_PrefsBase::EnumLdapuserrdn::cn: {
       QString cn = mCfg->ldapcnfullname() ? user.getFullName() : user.getName();
       if ( cn.isEmpty() ) cn = user.getName();
-      return "cn=" + cn;
+      return QLatin1String( "cn=" ) + cn;
     }
   }
-  return "";
+  return QLatin1String( "" );
 }
 
 void KU_UserLDAP::createPassword( KU_User &user, const QString &password )
@@ -278,12 +278,12 @@ void KU_UserLDAP::createPassword( KU_User &user, const QString &password )
       user.setPwd( password );
       break;
     case KU_PrefsBase::EnumLdappasswordhash::CRYPT:
-      user.setPwd( "{CRYPT}" + encryptPass( password, false ) );
+      user.setPwd( QLatin1String( "{CRYPT}" ) + encryptPass( password, false ) );
       break;
     case KU_PrefsBase::EnumLdappasswordhash::MD5: {
       QCryptographicHash md5(QCryptographicHash::Md5);
       md5.addData( password.toUtf8() );
-      user.setPwd( "{MD5}" + md5.result().toBase64() );
+      user.setPwd( QLatin1String( "{MD5}" ) + QLatin1String( md5.result().toBase64() ) );
       break;
     }
     case KU_PrefsBase::EnumLdappasswordhash::SMD5: {
@@ -292,14 +292,14 @@ void KU_UserLDAP::createPassword( KU_User &user, const QString &password )
       QByteArray pwd = password.toUtf8() + salt;
 
       md5.addData( pwd );
-      user.setPwd( "{SMD5}" + (md5.result() + salt).toBase64() );
+      user.setPwd( QLatin1String( "{SMD5}" ) + QLatin1String( (md5.result() + salt).toBase64() ) );
       break;
     }
     case KU_PrefsBase::EnumLdappasswordhash::SHA: {
       QCryptographicHash sha1(QCryptographicHash::Sha1);
 
       sha1.addData( password.toUtf8() );
-      user.setPwd( "{SHA}" + sha1.result().toBase64() );
+      user.setPwd( QLatin1String( "{SHA}" ) + QLatin1String( sha1.result().toBase64() ) );
       break;
     }
     case KU_PrefsBase::EnumLdappasswordhash::SSHA: {
@@ -309,7 +309,7 @@ void KU_UserLDAP::createPassword( KU_User &user, const QString &password )
       QByteArray pwd = password.toUtf8() + salt;
 
       sha1.addData( pwd );
-      user.setPwd( "{SSHA}" + (sha1.result() + salt).toBase64() );
+      user.setPwd( QLatin1String( "{SSHA}" ) + QLatin1String( (sha1.result() + salt).toBase64() ));
       break;
     }
   }
@@ -342,7 +342,7 @@ void KU_UserLDAP::createPassword( KU_User &user, const QString &password )
 
       user.setLMPwd( QString::fromLatin1( (const char*) &hex, 32 ) );
     } else {
-      user.setLMPwd( "" );
+      user.setLMPwd( QLatin1String( "" ) );
     }
   }
 }
@@ -351,11 +351,11 @@ void KU_UserLDAP::createModStruct( const KU_User &user, int oldindex, KLDAP::Lda
 {
   QString gecos, cn, pwd, samflags;
   QList<QByteArray> vals;
-  
+
   bool mod = ( oldindex != -1 );
 
   pwd = user.getPwd();
-  if ( user.getDisabled() ) pwd = "";
+  if ( user.getDisabled() ) pwd = QLatin1String( "" );
 
   cn = mCfg->ldapcnfullname() ? user.getFullName() : user.getName();
   if ( cn.isEmpty() ) cn = user.getName();
@@ -366,9 +366,9 @@ void KU_UserLDAP::createModStruct( const KU_User &user, int oldindex, KLDAP::Lda
     .arg(user.getOffice2())
     .arg(user.getAddress());
 
-  samflags = "[U";
-  samflags += user.getDisabled() ? 'D' : ' ';
-  samflags += "         ]";
+  samflags = QLatin1String( "[U" );
+  samflags += user.getDisabled() ? QLatin1Char( 'D' ) : QLatin1Char( ' ' );
+  samflags += QLatin1String( "         ]" );
 
   vals.append( caps & Cap_InetOrg ? "inetOrgPerson" : "account" );
   if ( user.getCaps() & KU_User::Cap_POSIX ) {
@@ -383,103 +383,103 @@ void KU_UserLDAP::createModStruct( const KU_User &user, int oldindex, KLDAP::Lda
 
   if ( mod && mObjectClasses.contains( oldindex ) ) {
     QStringList ocs = mObjectClasses[ oldindex ];
-    kDebug() << user.getName() << " has additional objectclasses: " << ocs.join(",");
+    kDebug() << user.getName() << " has additional objectclasses: " << ocs.join(QLatin1String( "," ));
     QStringList::iterator it;
     for ( it = ocs.begin(); it != ocs.end(); ++it ) {
       vals.append( (*it).toUtf8() );
     }
   }
-  ku_add2ops( ops, "objectClass", vals );
+  ku_add2ops( ops, QLatin1String( "objectClass" ), vals );
   vals.clear();
-  
-  ku_add2ops( ops, "cn", cn.toUtf8() );
-  ku_add2ops( ops, caps & Cap_InetOrg ? "uid" : "userid", user.getName().toUtf8() );
-  
+
+  ku_add2ops( ops, QLatin1String( "cn" ), cn.toUtf8() );
+  ku_add2ops( ops, caps & Cap_InetOrg ? QLatin1String( "uid" ) : QLatin1String( "userid" ), user.getName().toUtf8() );
+
   if ( ( user.getCaps() & KU_User::Cap_POSIX ) || ( caps & Cap_InetOrg ) ) {
-    ku_add2ops( ops, "userpassword", pwd.toUtf8(), true );
+    ku_add2ops( ops, QLatin1String( "userpassword" ), pwd.toUtf8(), true );
   }
 
   if ( user.getCaps() & KU_User::Cap_POSIX ) {
-    ku_add2ops( ops, "uidnumber", QString::number(user.getUID()).toUtf8() );
-    ku_add2ops( ops, "gidnumber", QString::number(user.getGID()).toUtf8() );
-    ku_add2ops( ops, "gecos", !mCfg->ldapgecos() ? QByteArray() : QByteArray( gecos.toLatin1() ) );
-    ku_add2ops( ops, "homedirectory", user.getHomeDir().toUtf8() );
-    ku_add2ops( ops, "loginshell", user.getShell().toUtf8() );
+    ku_add2ops( ops, QLatin1String( "uidnumber" ), QString::number(user.getUID()).toUtf8() );
+    ku_add2ops( ops, QLatin1String( "gidnumber" ), QString::number(user.getGID()).toUtf8() );
+    ku_add2ops( ops, QLatin1String( "gecos" ), !mCfg->ldapgecos() ? QByteArray() : QByteArray( gecos.toLatin1() ) );
+    ku_add2ops( ops, QLatin1String( "homedirectory" ), user.getHomeDir().toUtf8() );
+    ku_add2ops( ops, QLatin1String( "loginshell" ), user.getShell().toUtf8() );
   } else if (mod) {
-    ku_add2ops( ops, "uidnumber" );
-    ku_add2ops( ops, "gidnumber" );
-    ku_add2ops( ops, "gecos" );
-    ku_add2ops( ops, "homedirectory" );
-    ku_add2ops( ops, "loginshell" );
+    ku_add2ops( ops, QLatin1String( "uidnumber" ) );
+    ku_add2ops( ops, QLatin1String( "gidnumber" ) );
+    ku_add2ops( ops, QLatin1String( "gecos" ) );
+    ku_add2ops( ops, QLatin1String( "homedirectory" ) );
+    ku_add2ops( ops, QLatin1String( "loginshell" ) );
   }
 
   if ( caps & Cap_InetOrg ) {
-    ku_add2ops( ops, "sn", user.getSurname().toUtf8() );
-    ku_add2ops( ops, "mail", user.getEmail().toUtf8() );
-    ku_add2ops( ops, "displayName", user.getFullName().toUtf8() );
-    ku_add2ops( ops, "postaladdress", user.getAddress().toUtf8() );
+    ku_add2ops( ops, QLatin1String( "sn" ), user.getSurname().toUtf8() );
+    ku_add2ops( ops, QLatin1String( "mail" ), user.getEmail().toUtf8() );
+    ku_add2ops( ops, QLatin1String( "displayName" ), user.getFullName().toUtf8() );
+    ku_add2ops( ops, QLatin1String( "postaladdress" ), user.getAddress().toUtf8() );
     vals.append( user.getOffice1().toUtf8() );
     vals.append( user.getOffice2().toUtf8() );
-    ku_add2ops( ops, "telephoneNumber", vals );
+    ku_add2ops( ops, QLatin1String( "telephoneNumber" ), vals );
     vals.clear();
   }
 
   if ( caps & Cap_Samba ) {
     if ( user.getCaps() & KU_User::Cap_Samba ) {
-      ku_add2ops( ops, "sambadomainname", user.getDomain().toUtf8() );
-      ku_add2ops( ops, "sambauserworkstations", user.getWorkstations().toUtf8() );
-      ku_add2ops( ops, "sambahomepath", user.getHomePath().toUtf8() );
-      ku_add2ops( ops, "sambahomedrive", user.getHomeDrive().toUtf8() );
-      ku_add2ops( ops, "sambalogonscript", user.getLoginScript().toUtf8() );
-      ku_add2ops( ops, "sambaprofilepath", user.getProfilePath().toUtf8() );
-      ku_add2ops( ops, "sambalmpassword", user.getLMPwd().toUtf8() );
-      ku_add2ops( ops, "sambantpassword", user.getNTPwd().toUtf8() );
-      ku_add2ops( ops, "sambasid", user.getSID().getSID().toUtf8() );
-      ku_add2ops( ops, "sambaacctflags", samflags.toUtf8() );
-      ku_add2ops( ops, "sambaprimarygroupsid", user.getPGSID().getSID().toUtf8() );
-      ku_add2ops( ops, "sambapwdlastset", QString::number( user.getLastChange() ).toUtf8() );
+      ku_add2ops( ops, QLatin1String( "sambadomainname" ), user.getDomain().toUtf8() );
+      ku_add2ops( ops, QLatin1String( "sambauserworkstations" ), user.getWorkstations().toUtf8() );
+      ku_add2ops( ops, QLatin1String( "sambahomepath" ), user.getHomePath().toUtf8() );
+      ku_add2ops( ops, QLatin1String( "sambahomedrive" ), user.getHomeDrive().toUtf8() );
+      ku_add2ops( ops, QLatin1String( "sambalogonscript" ), user.getLoginScript().toUtf8() );
+      ku_add2ops( ops, QLatin1String( "sambaprofilepath" ), user.getProfilePath().toUtf8() );
+      ku_add2ops( ops, QLatin1String( "sambalmpassword" ), user.getLMPwd().toUtf8() );
+      ku_add2ops( ops, QLatin1String( "sambantpassword" ), user.getNTPwd().toUtf8() );
+      ku_add2ops( ops, QLatin1String( "sambasid" ), user.getSID().getSID().toUtf8() );
+      ku_add2ops( ops, QLatin1String( "sambaacctflags" ), samflags.toUtf8() );
+      ku_add2ops( ops, QLatin1String( "sambaprimarygroupsid" ), user.getPGSID().getSID().toUtf8() );
+      ku_add2ops( ops, QLatin1String( "sambapwdlastset" ), QString::number( user.getLastChange() ).toUtf8() );
       if ( user.getExpire() != -1 )
         vals.append( QString::number( user.getExpire() ).toUtf8() );
-      ku_add2ops( ops, "sambakickofftime", vals );
+      ku_add2ops( ops, QLatin1String( "sambakickofftime" ), vals );
       vals.clear();
     } else if (mod) {
-      ku_add2ops( ops, "sambadomainname" );
-      ku_add2ops( ops, "sambauserworkstations" );
-      ku_add2ops( ops, "sambahomepath" );
-      ku_add2ops( ops, "sambahomedrive" );
-      ku_add2ops( ops, "sambalogonscript" );
-      ku_add2ops( ops, "sambaprofilepath" );
-      ku_add2ops( ops, "sambalmpassword" );
-      ku_add2ops( ops, "sambantpassword" );
-      ku_add2ops( ops, "sambasid" );
-      ku_add2ops( ops, "sambaacctflags" );
-      ku_add2ops( ops, "sambaprimarygroupsid" );
-      ku_add2ops( ops, "sambapwdlastset" );
-      ku_add2ops( ops, "sambakickofftime" );
+      ku_add2ops( ops, QLatin1String( "sambadomainname" ) );
+      ku_add2ops( ops, QLatin1String( "sambauserworkstations" ) );
+      ku_add2ops( ops, QLatin1String( "sambahomepath" ) );
+      ku_add2ops( ops, QLatin1String( "sambahomedrive" ) );
+      ku_add2ops( ops, QLatin1String( "sambalogonscript" ) );
+      ku_add2ops( ops, QLatin1String( "sambaprofilepath" ) );
+      ku_add2ops( ops, QLatin1String( "sambalmpassword" ) );
+      ku_add2ops( ops, QLatin1String( "sambantpassword" ) );
+      ku_add2ops( ops, QLatin1String( "sambasid" ) );
+      ku_add2ops( ops, QLatin1String( "sambaacctflags" ) );
+      ku_add2ops( ops, QLatin1String( "sambaprimarygroupsid" ) );
+      ku_add2ops( ops, QLatin1String( "sambapwdlastset" ) );
+      ku_add2ops( ops, QLatin1String( "sambakickofftime" ) );
       if ( schemaversion > 0 ) {
-        ku_add2ops( ops, "sambapasswordhistory" );
-        ku_add2ops( ops, "sambalogonhours" );
+        ku_add2ops( ops, QLatin1String( "sambapasswordhistory" ) );
+        ku_add2ops( ops, QLatin1String( "sambalogonhours" ) );
       }
     }
   }
 
   if ( caps & Cap_Shadow ) {
     if ( user.getCaps() & KU_User::Cap_POSIX ) {
-      ku_add2ops( ops, "shadowlastchange",  QString::number( timeToDays( user.getLastChange() ) ).toUtf8() );
-      ku_add2ops( ops, "shadowmin", QString::number( user.getMin() ).toUtf8() );
-      ku_add2ops( ops, "shadowmax", QString::number( user.getMax() ).toUtf8() );
-      ku_add2ops( ops, "shadowwarning", QString::number( user.getWarn() ).toUtf8() );
-      ku_add2ops( ops, "shadowinactive", QString::number( user.getInactive() ).toUtf8() );
-      ku_add2ops( ops, "shadowexpire", QString::number( timeToDays( user.getExpire() ) ).toUtf8() );
-      ku_add2ops( ops, "shadowflag", QString::number( user.getFlag() ).toUtf8() );
+      ku_add2ops( ops, QLatin1String( "shadowlastchange" ),  QString::number( timeToDays( user.getLastChange() ) ).toUtf8() );
+      ku_add2ops( ops, QLatin1String( "shadowmin" ), QString::number( user.getMin() ).toUtf8() );
+      ku_add2ops( ops, QLatin1String( "shadowmax" ), QString::number( user.getMax() ).toUtf8() );
+      ku_add2ops( ops, QLatin1String( "shadowwarning" ), QString::number( user.getWarn() ).toUtf8() );
+      ku_add2ops( ops, QLatin1String( "shadowinactive" ), QString::number( user.getInactive() ).toUtf8() );
+      ku_add2ops( ops, QLatin1String( "shadowexpire" ), QString::number( timeToDays( user.getExpire() ) ).toUtf8() );
+      ku_add2ops( ops, QLatin1String( "shadowflag" ), QString::number( user.getFlag() ).toUtf8() );
     } else if (mod) {
-      ku_add2ops( ops, "shadowlastchange" );
-      ku_add2ops( ops, "shadowmin" );
-      ku_add2ops( ops, "shadowmax" );
-      ku_add2ops( ops, "shadowwarning" );
-      ku_add2ops( ops, "shadowinactive" );
-      ku_add2ops( ops, "shadowexpire" );
-      ku_add2ops( ops, "shadowflag" );
+      ku_add2ops( ops, QLatin1String( "shadowlastchange" ) );
+      ku_add2ops( ops, QLatin1String( "shadowmin" ) );
+      ku_add2ops( ops, QLatin1String( "shadowmax" ) );
+      ku_add2ops( ops, QLatin1String( "shadowwarning" ) );
+      ku_add2ops( ops, QLatin1String( "shadowinactive" ) );
+      ku_add2ops( ops, QLatin1String( "shadowexpire" ) );
+      ku_add2ops( ops, QLatin1String( "shadowflag" ) );
     }
   }
 }
@@ -520,9 +520,9 @@ bool KU_UserLDAP::dbcommit()
     QString newrdn = getRDN( it.value() );
 
     if ( oldrdn != newrdn ) {
-      int ret = op.rename_s( KLDAP::LdapDN( oldrdn + ',' + mUrl.dn().toString() ), 
-        newrdn, 
-        mUrl.dn().toString().toUtf8(),
+      int ret = op.rename_s( KLDAP::LdapDN( oldrdn + QLatin1Char( ',' ) + mUrl.dn().toString() ),
+        newrdn,
+                             QLatin1String( mUrl.dn().toString().toUtf8() ),
         true );
 
       if ( ret != KLDAP_SUCCESS ) {
@@ -535,7 +535,7 @@ bool KU_UserLDAP::dbcommit()
 
     ops.clear();
     createModStruct( it.value(), it.key(), ops );
-    int ret = op.modify_s( KLDAP::LdapDN( getRDN( it.value() ) + ',' + mUrl.dn().toString() ), ops );
+    int ret = op.modify_s( KLDAP::LdapDN( getRDN( it.value() ) + QLatin1Char( ',' ) + mUrl.dn().toString() ), ops );
     if ( ret != KLDAP_SUCCESS ) {
       mErrorString = KLDAP::LdapConnection::errorString(conn.ldapErrorCode());
       mErrorDetails = conn.ldapErrorString();
@@ -551,7 +551,7 @@ bool KU_UserLDAP::dbcommit()
     ops.clear();
     createModStruct( (*it), -1, ops );
     kDebug() << "add name: " << (*it).getName();
-    int ret = op.add_s( KLDAP::LdapDN( getRDN( (*it) ) + ',' + mUrl.dn().toString() ), ops );
+    int ret = op.add_s( KLDAP::LdapDN( getRDN( (*it) ) + QLatin1Char( ',' ) + mUrl.dn().toString() ), ops );
     if ( ret != KLDAP_SUCCESS ) {
       mErrorString = KLDAP::LdapConnection::errorString(conn.ldapErrorCode());
       mErrorDetails = conn.ldapErrorString();
@@ -565,7 +565,7 @@ bool KU_UserLDAP::dbcommit()
   //del
   for ( KU_Users::DelList::Iterator it = mDel.begin(); it != mDel.end(); ++it ) {
     kDebug() << "delete name: " << at((*it)).getName();
-    int ret = op.del_s( KLDAP::LdapDN( getRDN( at((*it)) ) + ',' + mUrl.dn().toString() ) );
+    int ret = op.del_s( KLDAP::LdapDN( getRDN( at((*it)) ) + QLatin1Char( ',' ) + mUrl.dn().toString() ) );
     if ( ret != KLDAP_SUCCESS ) {
       mErrorString = KLDAP::LdapConnection::errorString(conn.ldapErrorCode());
       mErrorDetails = conn.ldapErrorString();
@@ -575,7 +575,7 @@ bool KU_UserLDAP::dbcommit()
       mDelSucc.append( (*it) );
     }
   }
-                               
+
   delete mProg;
   return true;
 }
